@@ -18,11 +18,18 @@ def register(excelFile: "Excel file containing the component data",
              project: "ATLAS Project" = "S",
              subProject: "ATLAS Subproject" = "SE",
              institution: "Institute doing the registration" = "DESYHH",
-             subType: "Component Subtype" = "THERMALFOAMSET_PETAL"
+             subType: "Component Subtype" = "THERMALFOAMSET_PETAL",
+             lambdaFunction: "Function that modifies the df (takes the df as argument, returns the modified df)" = None
              ):
     "Registering components from an excel file."
     df = pd.read_excel(excelFile, header=1)
     print(df)
+    if lambdaFunction is not None:
+        df = lambdaFunction(df)
+        logger.info("Modified the dataframe")
+        assert isinstance(df, pd.DataFrame)
+        print(df)
+
     for i, r in df.iterrows():
         JSON = {}
         JSON['institution'] = institution
